"""
Production Environment - Google Cloud Infrastructure
Generated by InfraDSL init command
"""

# Google Cloud Infrastructure for production environment
from infradsl import GoogleCloud

# Compute Engine VM
web_server = (GoogleCloud.VM("web-server")
    .e2_micro()
    .ubuntu()
    .service("nginx")
    .public_ip()
    .create())

# Cloud SQL Database
database = (GoogleCloud.CloudSQL("app-db")
    .postgresql()
    .db_f1_micro()
    .storage(10)
    .create())

# Cloud Storage
storage = (GoogleCloud.Storage("app-assets")
    .bucket()
    .public()
    .lifecycle(30)
    .create())

print(f"✅ Production environment infrastructure created!")
print(f"🌐 Web server: {web_server['ip_address']}")
print(f"🗄️  Database: {database['connection_name']}")
print(f"📦 Storage: {storage['bucket_name']}")
