"""
IntelligentApplication - Modular Cross-Cloud Magic System

This module provides the revolutionary developer experience for automatic 
cross-cloud provider selection and optimization.
"""

from .core import IntelligentApplication, OptimizationPreferences, ServiceConfiguration

__all__ = ['IntelligentApplication', 'OptimizationPreferences', 'ServiceConfiguration']