"""Version information for InfraDSL."""

__version__ = "0.1.2"
__version_info__ = tuple(int(i) for i in __version__.split('.') if i.isdigit())

# Release metadata
__title__ = "infradsl"
__description__ = "Rails-like infrastructure management for AWS, Google Cloud, DigitalOcean and Azure"
__author__ = "InfraDSL Team"
__author_email__ = "hello@infradsl.dev"
__url__ = "https://github.com/infradsl/infradsl"
__license__ = "MIT"
__copyright__ = "Copyright 2024-2025 InfraDSL Team"
