#!/usr/bin/env python3
"""
InfraDSL CLI Main Entry Point

This allows the CLI package to be executed with `python -m infradsl.cli`
"""

from infradsl.cli import cli

if __name__ == "__main__":
    cli()