"""
Development Environment - DigitalOcean Infrastructure
Generated by InfraDSL init command
"""

# DigitalOcean Infrastructure for development environment
from infradsl import DigitalOcean

# Droplet (VM)
web_server = (DigitalOcean.Droplet("web-server")
    .basic()
    .ubuntu()
    .service("nginx")
    .public_ip()
    .create())

# Load Balancer
load_balancer = (DigitalOcean.LoadBalancer("app-lb")
    .http(80)
    .health_check("/")
    .add_droplet(web_server)
    .create())

# Container Registry
registry = (DigitalOcean.ContainerRegistry("app-registry")
    .basic()
    .create())

print(f"✅ Development environment infrastructure created!")
print(f"🌐 Web server: {web_server['ip_address']}")
print(f"⚖️  Load balancer: {load_balancer['ip_address']}")
print(f"📦 Registry: {registry['registry_name']}")
