"""
Google Cloud Analytics Managers

This module contains managers for Google Cloud analytics services like BigQuery.
"""

from .bigquery_manager import BigQueryManager

__all__ = ['BigQueryManager']
